@@ -80,7 +80,6 @@ def to_stamp(format_time):
 def to_date(start):
     """
     start = ['567100800', '1632844924200'] --->支持10位，13位时间戳转标准时间
-    start = '2022-09-06 00:15:01' ---> 支持标准时间转10位时间戳
     :param start:
     :return:
     """
@@ -122,7 +121,7 @@ def SaveExcel(filename, data, Excel_head):
     try:
         # 创建保存excel表格的文件夹
         # os.getcwd() 获取当前文件路径
-        os_mkdir_path = os.getcwd() + '/数据/'
+        os_mkdir_path = os.getcwd() + '/EXCEL数据/'
         # 判断这个路径是否存在，不存在就创建
         if not os.path.exists(os_mkdir_path):
             os.mkdir(os_mkdir_path)
@@ -461,6 +460,8 @@ def mkdir(dir_name):
         print(f'路径存在:{os_mkdir_path}')
 
 
+tqdm = td
+
 video_pojie = lambda url: 'http://okjx.cc/?url=' + url
 """
 支持众多主流视频站点:API拼接网页链接，访问即可
@@ -490,16 +491,18 @@ def html_nodes_text(XPATH_list):
     return text_list
 
 
-def console(self, *args, sep=' ', end='\n', file=None, color=None, model=True):
+def console(self, *args, sep=' ', end='\n', file=None, color=None, model=True, colorful=False):
     """
+
     :param self:
     :param args:
-    :param sep:
-    :param end:
+    :param sep: Type == str
+    :param end: Type == str
     :param file:
-    :param color: if model == True --> color = '黄色'
-                  if model == False --> color = 'Fore.YELLOW'
-    :return:
+    :param color: Type == str
+    :param model: Type == bool
+    :param colorful: Type == bool
+    :return: print
     """
     dic = {
         '黄色': 'Fore.YELLOW', '+黄色': 'Fore.LIGHTYELLOW_EX',
@@ -507,16 +510,65 @@ def console(self, *args, sep=' ', end='\n', file=None, color=None, model=True):
         '青色': 'Fore.CYAN', '+青色': 'Fore.LIGHTCYAN_EX',
         '绿色': 'Fore.GREEN', '+绿色': 'Fore.LIGHTGREEN_EX',
         '蓝色': 'Fore.BLUE', '+蓝色': 'Fore.LIGHTBLUE_EX',
-        '黑色': 'Fore.BLACK', '+黑色': 'Fore.LIGHTBLACK_EX',
-        '品红色': 'Fore.MAGENTA', '+白色': 'Fore.LIGHTWHITE_EX'
+        # '黑色': 'Fore.BLACK', '+黑色': 'Fore.LIGHTBLACK_EX',
+        '品红色': 'Fore.MAGENTA', '+品红色': 'Fore.LIGHTMAGENTA_EX',
+        '!': 'Fore.RESET'
     }
-    if color != None:
-        if model != False:
-            color = eval(dic[color])
-        else:
-            color = eval(color)
-    else:
-        color = Fore.LIGHTYELLOW_EX
-    print(color + str(self), *args, sep=sep, end=end, file=file)
+    if colorful == True:
+        li = list(str(self))
+        for nnn in li:
+            print(eval(dic[random.sample(dic.keys(), 1)[0]]) + nnn, end='')
+        print('', end='  ')
+        for iii in args:
+            iii = list(str(iii))
 
-tqdm = td
+            for ppp in iii:
+                # breakpoint()
+                print(eval(dic[random.sample(dic.keys(), 1)[0]]) + ppp, end='', )
+            print('', end='  ')
+        print('\n', end='')
+
+    else:
+        if color != None:
+            if model != False:
+                color = eval(dic[color])
+            else:
+                color = eval(color)
+        else:
+            color = Fore.LIGHTYELLOW_EX
+
+        print(color + str(self), *args, sep=sep, end=end, file=file)
+
+
+def mini_dom(node_list, title='The DOM tree reconstruction', sep='<p>\n**********\n</p>'):
+    """
+    :param node_list: Type == list
+    :param title: Type == str
+    :param sep: Type == str
+    :return: New Dom Tree   Type == str
+    """
+    all_html_nodes = []
+    for node in node_list:
+        node_to_html = str(etree.tostring(node)).lstrip("b'").rstrip("'").replace(r'\n', '\n')
+        all_html_nodes.append(node_to_html)
+    # <!-- -->
+    node_to_html = sep.join(all_html_nodes)
+    dom = html.unescape(f"""
+            <!--JR-->
+            <!DOCTYPE html>
+            <html lang="en">
+            <head>
+                <meta charset="UTF-8">
+                <title>{title}</title>
+            </head>
+            <body>
+                {node_to_html}
+            </body>
+            </html>
+            """)
+    return dom
+
+
+re = re
+
+etree = etree
